SmartRetry class

Main retry executor.

Constructors

SmartRetry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

execute<T>(Future<T> action(), {required RetryOptions options}) Future<T>
Execute a function with retry logic.
executeSync<T>(T action(), {required RetryOptions options}) → T
Execute a synchronous function with retry logic.
retryable<T>(Future<T> action(), {required RetryOptions options}) Future<T> Function()
Helper to create a retryable function.